@@ -4,7 +4,7 @@
 
 void ffDetectLocale(FFstrbuf* result)
 {
-    ffStrbufAppendS(result, getenv("LC_MESSAGES"));
+    ffStrbufAppendS(result, getenv("LC_ALL"));
     if(result->length > 0)
         return;
 
@@ -12,11 +12,5 @@ void ffDetectLocale(FFstrbuf* result)
     if(result->length > 0)
         return;
 
-    #ifdef LC_MESSAGES
-    ffStrbufAppendS(result, setlocale(LC_MESSAGES, NULL));
-    if(result->length > 0)
-        return;
-    #endif
-
     ffStrbufAppendS(result, setlocale(LC_TIME, NULL));
 }
