@@ -1,13 +1,13 @@
 #include "fastfetch.h"
-#include "common/commandoption.h"
-#include "common/init.h"
-#include "common/io/io.h"
-#include "common/jsonconfig.h"
-#include "common/time.h"
 #include "detection/version/version.h"
 #include "logo/logo.h"
-#include "util/stringUtils.h"
-#include "util/mallocHelper.h"
+#include "common/commandoption.h"
+#include "common/init.h"
+#include "common/io.h"
+#include "common/jsonconfig.h"
+#include "common/time.h"
+#include "common/stringUtils.h"
+#include "common/mallocHelper.h"
 #include "fastfetch_datatext.h"
 
 #include <stdlib.h>
@@ -15,7 +15,7 @@
 #include <string.h>
 
 #ifdef _WIN32
-    #include "util/windows/getline.h"
+    #include "common/windows/getline.h"
 #endif
 
 static void printCommandFormatHelpJson(void)
@@ -442,7 +442,9 @@ static void generateConfigFile(bool force, const char* filePath, bool fullConfig
             exit(477);
         }
 
-        ffStrbufSet(&instance.state.genConfigPath, FF_LIST_GET(FFstrbuf, instance.state.platform.configDirs, 0));
+        FFstrbuf* configDir = FF_LIST_FIRST(FFstrbuf, instance.state.platform.configDirs);
+        ffStrbufEnsureFixedLengthFree(&instance.state.genConfigPath, configDir->length + strlen("fastfetch/config.jsonc"));
+        ffStrbufSet(&instance.state.genConfigPath, configDir);
         ffStrbufAppendS(&instance.state.genConfigPath, "fastfetch/config.jsonc");
     }
     else
@@ -486,7 +488,8 @@ static void optionParseConfigFile(FFdata* data, const char* key, const char* val
 
     //Try to load as an absolute path
 
-    FF_STRBUF_AUTO_DESTROY absolutePath = ffStrbufCreateS(value);
+    FF_STRBUF_AUTO_DESTROY absolutePath = ffStrbufCreateA(128);
+    ffStrbufSetS(&absolutePath, value);
     bool strictJson = ffStrbufEndsWithIgnCaseS(&absolutePath, ".json");
     bool jsonc = !strictJson && ffStrbufEndsWithIgnCaseS(&absolutePath, ".jsonc");
     bool json5 = !strictJson && !jsonc && ffStrbufEndsWithIgnCaseS(&absolutePath, ".json5");
