@@ -1,24 +1,17 @@
 #include "logo/logo.h"
-#include "common/io/io.h"
+#include "common/io.h"
 #include "common/printing.h"
 #include "common/processing.h"
+#include "common/textModifier.h"
+#include "common/stringUtils.h"
 #include "detection/media/media.h"
 #include "detection/os/os.h"
 #include "detection/terminalshell/terminalshell.h"
-#include "util/textModifier.h"
-#include "util/stringUtils.h"
 
 #include <ctype.h>
 #include <stdlib.h>
 #include <string.h>
 
-typedef enum __attribute__((__packed__)) FFLogoSize
-{
-    FF_LOGO_SIZE_UNKNOWN,
-    FF_LOGO_SIZE_NORMAL,
-    FF_LOGO_SIZE_SMALL,
-} FFLogoSize;
-
 static bool ffLogoPrintCharsRaw(const char* data, size_t length, bool printError)
 {
     FFOptionsLogo* options = &instance.config.logo;
@@ -451,7 +444,7 @@ static bool logoPrintBuiltinIfExists(const FFstrbuf* name, FFLogoSize size)
         return true;
     }
 
-    const FFlogo* logo = ffStrbufEqualS(name, "?") ? &ffLogoUnknown : logoGetBuiltin(name, size);
+    const FFlogo* logo = ffLogoGetBuiltinForName(name, size);
     if(logo == NULL)
         return false;
 
@@ -494,7 +487,7 @@ static bool updateLogoPath(void)
         return true;
     }
 
-    FF_STRBUF_AUTO_DESTROY fullPath = ffStrbufCreate();
+    FF_STRBUF_AUTO_DESTROY fullPath = ffStrbufCreateA(128);
     if (ffPathExpandEnv(options->source.chars, &fullPath) && ffPathExists(fullPath.chars, FF_PATHTYPE_FILE))
     {
         ffStrbufDestroy(&options->source);
@@ -733,22 +726,23 @@ void ffLogoPrintRemaining(void)
 void ffLogoBuiltinPrint(void)
 {
     FFOptionsLogo* options = &instance.config.logo;
+    options->position = FF_LOGO_POSITION_TOP;
+    options->paddingRight = 2; // empty line after logo printing
+    FF_STRBUF_AUTO_DESTROY buf = ffStrbufCreate();
 
     for(uint8_t ch = 0; ch < 26; ++ch)
     {
         for(const FFlogo* logo = ffLogoBuiltins[ch]; *logo->names; ++logo)
         {
-            printf("\033[%sm%s:\033[0m\n", logo->colors[0], logo->names[0]);
+            if (instance.config.display.pipe)
+                ffStrbufSetF(&buf, "%s:\n", logo->names[0]);
+            else
+                ffStrbufSetF(&buf, "\e[%sm%s:\e[0m\n", logo->colors[0], logo->names[0]);
+            ffWriteFDBuffer(FFUnixFD2NativeFD(STDOUT_FILENO), &buf);
             logoPrintStruct(logo);
-            ffLogoPrintRemaining();
 
-            //reset everything
-            instance.state.logoHeight = 0;
-            instance.state.keysHeight = 0;
             for(uint8_t i = 0; i < FASTFETCH_LOGO_MAX_COLORS; i++)
                 ffStrbufClear(&options->colors[i]);
-
-            putchar('\n');
         }
     }
 }
@@ -783,3 +777,13 @@ void ffLogoBuiltinListAutocompletion(void)
             printf("%s\n", logo->names[0]);
     }
 }
+
+const FFlogo* ffLogoGetBuiltinForName(const FFstrbuf* name, FFLogoSize size)
+{
+    return ffStrbufEqualS(name, "?") ? &ffLogoUnknown : logoGetBuiltin(name, size);
+}
+
+const FFlogo* ffLogoGetBuiltinDetected(FFLogoSize size)
+{
+    return logoGetBuiltinDetected(size);
+}
